@@ -8,7 +8,7 @@ use Class::Utils qw(set_params split_params);
 use Error::Pure qw(err);
 use Scalar::Util qw(blessed);
 
-our $VERSION = 0.04;
+our $VERSION = 0.05;
 
 # Constructor.
 sub new {
@@ -16,12 +16,15 @@ sub new {
 
 	# Create object.
 	my ($object_params_ar, $other_params_ar) = split_params(
-		['css_messages'], @params);
+		['css_messages', 'flag_no_messages'], @params);
 	my $self = $class->SUPER::new(@{$other_params_ar});
 
 	# CSS class.
 	$self->{'css_messages'} = 'messages';
 
+	# Flag for no messages.
+	$self->{'flag_no_messages'} = 1;
+
 	# Process params.
 	set_params($self, @{$object_params_ar});
 
@@ -51,6 +54,11 @@ sub _process {
 
 	$self->_check_messages($message_ar);
 
+	# No messages.
+	if (! $self->{'flag_no_messages'} && ! @{$message_ar}) {
+		return;
+	}
+
 	my $num = 0;
 	$self->{'tags'}->put(
 		['b', 'div'],
@@ -86,13 +94,19 @@ sub _process {
 
 # Process 'CSS::Struct'.
 sub _process_css {
-	my ($self, $type, $color) = @_;
+	my ($self, $message_types_hr) = @_;
 
-	$self->{'css'}->put(
-		['s', '.'.$type],
-		['d', 'color', $color],
-		['e'],
-	);
+	if (! defined $message_types_hr || ref $message_types_hr ne 'HASH') {
+		return;
+	}
+
+	foreach my $message_type (keys %{$message_types_hr}) {
+		$self->{'css'}->put(
+			['s', '.'.$message_type],
+			['d', 'color', $message_types_hr->{$message_type}],
+			['e'],
+		);
+	}
 
 	return;
 }
@@ -139,6 +153,17 @@ CSS class for main messages div block.
 
 Default value is 'messages'.
 
+=item * C<flag_no_messages>
+
+Flag for no messages printing.
+
+Possible values:
+
+ 0 - Print nothing
+ 1 - Print message box with 'No messages.' text.
+
+Default value is 1.
+
 =item * C<tags>
 
 'Tags::Output' object.
@@ -160,12 +185,12 @@ Returns undef.
 
 =head2 C<process_css>
 
- $obj->process_css($type, $color);
+ $obj->process_css($message_types_hr);
 
 Process CSS::Struct structure for output.
 
-Variable C<$type> is string which define message type. Possible values are info
-and error now. Types are defined in L<Data::Message::Simple>.
+Variable C<$message_type_hr> is reference to hash with keys for message type and value for color in CSS style.
+Possible message types are info and error now. Types are defined in L<Data::Message::Simple>.
 
 Returns undef.
 
@@ -236,8 +261,10 @@ Returns undef.
  ];
 
  # Process page.
- $messages->process_css('error', 'red');
- $messages->process_css('info', 'green');
+ $messages->process_css({
+         'error' => 'red',
+         'info' => 'green',
+ });
  $begin->process;
  $messages->process($message_ar);
  $end->process;
@@ -310,6 +337,6 @@ BSD 2-Clause License
 
 =head1 VERSION
 
-0.04
+0.05
 
 =cut
